Recipes
=======
Collection of recipes & recommendations to use **coredis**
for common application patterns. These recipes are shipped as
part of the library under the :mod:`coredis.recipes` namespace.

Some of these recipes may require additional dependencies that
are not installed by default with the :pypi:`coredis` package.
To ensure all dependencies required by the recipes are installed,
use the ``[recipes]`` extra::

    pip install coredis[recipes]

.. toctree::
    :maxdepth: 2

    credentials
    locks
